@@ -1,9 +1,9 @@
 package Tapper::Reports::API;
-# git description: v4.1.2-14-g8d0c145
+# git description: v5.0.0-2-g45b4d91
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Remote network API for result evaluation
-$Tapper::Reports::API::VERSION = '5.0.0';
+$Tapper::Reports::API::VERSION = '5.0.1';
 use 5.010;
 use strict;
 use warnings;
@@ -131,7 +131,7 @@ sub _parse_args {
 sub handle_mason
 {
         my ($self, @args) = @_;
-        do { print "Mason is not enabled\n"; return } unless Tapper::Config->subconfig->{reports_enable_mason};
+        do { print "Mason is not enabled. Set reports_enable_mason: 1 in ".Tapper::Config->subconfig->{_last_used_tapper_config_file}.".\n"; return } unless Tapper::Config->subconfig->{reports_enable_mason};
 
         my %args = _parse_args(@args[0..$#args-1]);
         my $payload = $self->get_payload(@args);
